summaryrefslogtreecommitdiff
path: root/sc/source/ui/unoobj/docuno.cxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-11-05 11:33:34 +0200
committerNoel Grandin <noel@peralex.com>2015-11-05 12:02:00 +0200
commit609b22787392be4c2eac6fe098a70341a4c204e4 (patch)
tree75a40671862b9dbe2c8acd6e0e6fbeb39a8c1ac2 /sc/source/ui/unoobj/docuno.cxx
parent2fe02d55d72a808dd79ba9529bc5078a45175c16 (diff)
fix tdf#95488, crash in report wizard
This reverts commit bb76b8f10697f3d5ca1f9a2f19902b043bd61cd7 "loplugin:mergeclasses" Change-Id: Ib65459ab45cd4cefa859ed75f9ddc4f070879b1d
Diffstat (limited to 'sc/source/ui/unoobj/docuno.cxx')
-rw-r--r--sc/source/ui/unoobj/docuno.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/sc/source/ui/unoobj/docuno.cxx b/sc/source/ui/unoobj/docuno.cxx
index 45e5db953223..f8e85de85b92 100644
--- a/sc/source/ui/unoobj/docuno.cxx
+++ b/sc/source/ui/unoobj/docuno.cxx
@@ -2424,14 +2424,14 @@ css::uno::Reference<css::uno::XInterface> ScModelObj::create(
}
else
{
// alles was ich nicht kenn, werf ich der SvxUnoDrawMSFactory an den Hals,
// da wird dann 'ne Exception geworfen, wenn's nicht passt...
try
{
xRet = arguments == 0
- ? SvxUnoDrawMSFactory::createInstance(aServiceSpecifier)
- : SvxUnoDrawMSFactory::createInstanceWithArguments(
+ ? SvxFmMSFactory::createInstance(aServiceSpecifier)
+ : SvxFmMSFactory::createInstanceWithArguments(
aServiceSpecifier, *arguments);
// extra block to force deletion of the temporary before ScShapeObj ctor (setDelegator)
}
@@ -2490,10 +2490,10 @@ uno::Sequence<OUString> SAL_CALL ScModelObj::getAvailableServiceNames()
//! warum sind die Parameter bei concatServiceNames nicht const ???
//! return concatServiceNames( ScServiceProvider::GetAllServiceNames(),
- //! SvxUnoDrawMSFactory::getAvailableServiceNames() );
+ //! SvxFmMSFactory::getAvailableServiceNames() );
uno::Sequence<OUString> aMyServices(ScServiceProvider::GetAllServiceNames());
- uno::Sequence<OUString> aDrawServices(SvxUnoDrawMSFactory::getAvailableServiceNames());
+ uno::Sequence<OUString> aDrawServices(SvxFmMSFactory::getAvailableServiceNames());
return concatServiceNames( aMyServices, aDrawServices );
}
@@ -2424,14 +2424,14 @@ css::uno::Reference<css::uno::XInterface> ScModelObj::create(
else
{
- // alles was ich nicht kenn, werf ich der SvxUnoDrawMSFactory an den Hals,
+ // alles was ich nicht kenn, werf ich der SvxFmMSFactory an den Hals,
// da wird dann 'ne Exception geworfen, wenn's nicht passt...
try